;;; eldoc --- The eldoc cubes for FG42 -*- lexical-binding: t; -*-
;;
;; Copyright (c) 2010-2022 Sameer Rahmani & Contributors
;;
;; Author: Sameer Rahmani <lxsameer@gnu.org>
;; URL: https://gitlab.com/FG42/FG42
;; Version: 3.0.0
;;
;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;
;;; Commentary:
;; Cubes are the building blocks of any `FG42' editor.  Each `cube' is a
;; unit which defines different abilities in a deterministic and idempotent
;; way.  Cubes are composable and a composition of cubes creates an editor.
;;
;;; Code:
(require 'fpkg)
(require 'fg42/cube)


(defcube fg42/eldoc-box-cube
  "This cube sets up the =eldoc-box= system to show documentations on demand in
a box."
  (:title "Eldoc box Cube"
         :flag eldoc-box
         :flag-default t
         :modes '(eldoc-box-hover-mode eldoc-box-hover-at-point-mode))
  (fpkg/use eldoc-box
    :config
    (add-hook 'eldoc-mode-hook 'eldoc-box-hover-at-point-mode)))


(provide 'cubes/eldoc)
;;; eldoc.el ends here
